/************************************************************************************
The code is designed and produced by MDY Science and Education Co., Ltd, which has the entire ownership. It is only for personal learning, which cannot be used for commercial or profit-making purposes without permission.

    MDY's Mission: Develop Chip Talents and Realize National Chip Dream.

    We sincerely hope that our students can learn the real IC / FPGA code through our standard and rigorous code.

    For more FPGA learning materials, please visit the Forum: http://fpgabbs.com/ and official website: http://www.mdy-edu.com/index.html 

    *************************************************************************************/

module seg_disp(
    clk         ,
    rst_n       ,
    segment_data,
    segment     ,
    seg_sel      
);

parameter   ZERO           =   8'b1100_0000          ;
parameter   ONE            =   8'b1111_1001          ;
parameter   TWO            =   8'b1010_0100          ;
parameter   THREE          =   8'b1011_0000          ;
parameter   FOUR           =   8'b1001_1001          ;
parameter   FIVE           =   8'b1001_0010          ;
parameter   SIX            =   8'b1000_0010          ;
parameter   SEVEN          =   8'b1111_1000          ;
parameter   EIGHT          =   8'b1000_0000          ;
parameter   NINE           =   8'b1001_0000          ;

input             clk             ;         
input             rst_n           ;   
input    [31:0]   segment_data    ;
output   [7:0 ]   segment         ; 
output   [7:0 ]   seg_sel         ;

reg      [7:0 ]   segment         ;
reg      [7:0 ]   seg_sel         ;
reg      [10:0]   delay           ;
reg      [3:0 ]   delay_time      ;
wire              add_delay_time  ;
wire              end_delay_time  ;
wire              add_delay       ;
wire              end_delay       ;
wire     [3:0 ]   segment_tmp     ;




always @(posedge clk or negedge rst_n) begin 
    if (rst_n==0) begin
        delay <= 0; 
    end
    else if(add_delay) begin
        if(end_delay)
            delay <= 0; 
        else
            delay <= delay+1 ;
   end
end
assign add_delay = 1;
assign end_delay = add_delay  && delay == 2000-1 ;




always @(posedge clk or negedge rst_n) begin 
    if (rst_n==0) begin
        delay_time <= 0; 
    end
    else if(add_delay_time) begin
        if(end_delay_time)
            delay_time <= 0; 
        else
            delay_time <= delay_time+1 ;
   end
end
assign add_delay_time = end_delay;
assign end_delay_time = add_delay_time  && delay_time == 8-1 ;


assign segment_tmp  = segment_data[(1+delay_time)*4-1 -:4];
always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        segment <= ZERO;
    end
    else begin
        case(segment_tmp)
            4'd0:segment <= ZERO;
            4'd1:segment <= ONE  ;
            4'd2:segment <= TWO  ;
            4'd3:segment <= THREE;
            4'd4:segment <= FOUR ;
            4'd5:segment <= FIVE ;
            4'd6:segment <= SIX  ;
            4'd7:segment <= SEVEN;
            4'd8:segment <= EIGHT;
            4'd9:segment <= NINE ;
            default:begin
                segment <= segment;
            end
        endcase
    end
end


always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        seg_sel <= 8'b1111_1111;
    end
    else begin
        seg_sel <= ~(8'b1<<delay_time);
    end
end


endmodule
